pub struct IntroduceVariableOutcome {
pub plan: RefactoringPlan,
pub name: String,
pub inserted_line: usize,
pub replaced_start: usize,
pub replaced_end: usize,
}Expand description
Outcome of a successful introduce-variable plan.
Fields
plan: RefactoringPlanname: StringThe variable name that was introduced.
inserted_line: usize1-based line number where the let binding was inserted.
replaced_start: usizeByte range that was replaced with the variable name.
replaced_end: usizeAuto Trait Implementations
impl Freeze for IntroduceVariableOutcome
impl RefUnwindSafe for IntroduceVariableOutcome
impl Send for IntroduceVariableOutcome
impl Sync for IntroduceVariableOutcome
impl Unpin for IntroduceVariableOutcome
impl UnsafeUnpin for IntroduceVariableOutcome
impl UnwindSafe for IntroduceVariableOutcome